
// AnimM3G.java
// Andrew Davison, dandrew@ratree.psu.ac.th, October 2004

/* A penguin walking in a circle.
   Illustrates: retained mode, animation controllers, tracks,
   and keyframe sequences.

   The scene graph includes a light, a camera, a background,
   and mesh representing the penguin model and the floor.

   There are two animations: translation and rotation, both
   applied to the penguin model.

   The penguin model was created in MilkShape 3D 1.7.1
   (http://www.swissquake.ch/chumbalum-soft/ms3d/), exported as
   a Wavefront OBJ file, then converted to coordinates, normals, etc
   using ObjView.

   The rendering mixes 3D and 2D: the 3D scene is drawn first, then
   a string is added using drawString().

   My thanks to Kari Pulli, Tomi Aarnio, and Kari J. Kangas for help 
   with understanding animation using keyframe sequences.
*/

import javax.microedition.lcdui.*;
import javax.microedition.midlet.*;
import java.util.*;


public class AnimM3G extends MIDlet
{
  private static final int PERIOD = 50;   // in ms

  private Timer timer;
  private AnimCanvas animCanvas = null;

  public AnimM3G()
  { timer = new Timer();  
    animCanvas = new AnimCanvas(this);
  }


  public void startApp() 
  { Display.getDisplay(this).setCurrent( animCanvas );
    timer.schedule( new AnimTimer(), 0, PERIOD);   // tick every PERIOD ms
  }
  
  public void pauseApp() {}

  public void destroyApp(boolean unconditional) {}

  public void finishGame()
  { timer.cancel();    // stop the timer
    notifyDestroyed();  
  }


  // -------------------------------------------

  class AnimTimer extends TimerTask 
  {
    public void run() 
    { if(animCanvas != null)
        animCanvas.update();   // update the scene
    }
  } // end of AnimTask()

} // end of AnimM3G class
